<?php
// Add a submenu page under the CF7 main menu
function cf7_stylesheet_add_admin_menu() {
    add_submenu_page(
        'wpcf7',
        'CF7 Stylesheet Settings',
        'Stylesheet Settings',
        'manage_options',
        'cf7-stylesheet-settings',
        'cf7_stylesheet_settings_page'
    );
}
add_action('admin_menu', 'cf7_stylesheet_add_admin_menu');

// Render the settings page
function cf7_stylesheet_settings_page() {
    ?>
    <div class="wrap">
        <h1>CF7 Stylesheet Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('cf7_stylesheet_settings_group');
            do_settings_sections('cf7_stylesheet_settings');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

// Register and define the settings
function cf7_stylesheet_settings_init() {
    register_setting('cf7_stylesheet_settings_group', 'cf7_default_stylesheet');

    add_settings_section(
        'cf7_stylesheet_settings_section',
        'Default Stylesheet Settings',
        'cf7_stylesheet_settings_section_callback',
        'cf7_stylesheet_settings'
    );

    add_settings_field(
        'cf7_default_stylesheet',
        'Default Stylesheet',
        'cf7_default_stylesheet_render',
        'cf7_stylesheet_settings',
        'cf7_stylesheet_settings_section'
    );
}
add_action('admin_init', 'cf7_stylesheet_settings_init');

function cf7_stylesheet_settings_section_callback() {
    echo 'Choose the default stylesheet to be used if none is selected for an individual form.';
}

function cf7_default_stylesheet_render() {
    $default_style = get_option('cf7_default_stylesheet', 'cf7-stylesheet');

    $stylesheets = [
        'cf7-stylesheet' => 'Default Style',
        'cf7-stylesheet-big' => 'Big Style',
        'cf7-stylesheet-big-dark' => 'Big Dark Style',
        'cf7-stylesheet-small' => 'Small Style',
        'cf7-stylesheet-small-dark' => 'Small Dark Style',
        'cf7-stylesheet-bootstrap' => 'Bootstrap Style',
        'cf7-stylesheet-border' => 'Border Style',
        'cf7-stylesheet-round' => 'Round Style',
        'cf7-stylesheet-colorful' => 'Colorful Style',
        'cf7-stylesheet-digital' => 'Digital Style',
        'cf7-stylesheet-digital-dark' => 'Digital Dark Style'
    ];

    echo '<select name="cf7_default_stylesheet">';
    foreach ($stylesheets as $value => $label) {
        $selected = ($value == $default_style) ? 'selected="selected"' : '';
        echo '<option value="' . esc_attr($value) . '" ' . $selected . '>' . esc_html($label) . '</option>';
    }
    echo '</select>';
}
?>
